embassy-stm32

Crates

git

Versions

stm32h562ai

Flavors

BackupMemory

Struct BackupMemory 

pub struct BackupMemory { /* private fields */ }
Struct used to initilize backup sram

Implementations

Source

impl BackupMemory

pub fn new(_backup_sram: Peri<'static, BKPSRAM>) -> Self

Setup battery backed sram

Returns slice to sram and whether the sram was retained

pub fn is_retained(&self) -> bool

Returns true if the sram was retained across last reset

pub fn as_ptr(&self) -> *mut u8

Get raw pointer to the battery backed memory

Note that this is not necesserily normal memory, so please do use volatile and aligned reads/writes unless you know what you are doing.

pub fn size(&self) -> usize

Size of backup sram

pub fn read(&mut self, address: usize, dst: &mut [u8])

Write single byte to backup sram

Address is relative start of backup sram

pub fn write(&mut self, address: usize, src: &[u8])

Write single byte to backup sram

Address is relative start of backup sram